Authoring Assignments
=====================

**e2xgrader** comes with a built-in component for authoring assignments.
For an extensive documentation about the authoring component head over to the `e2xauthoring documentation <http://e2xauthoring.readthedocs.io>`_